@@ -5,7 +5,8 @@ use super::{
     Component, DrawableComponent, FileTreeComponent,
 };
 use crate::{
-    accessors, queue::Queue, strings, ui::style::SharedTheme,
+    accessors, keys::SharedKeyConfig, queue::Queue, strings,
+    ui::style::SharedTheme,
 };
 use anyhow::Result;
 use asyncgit::{
@@ -26,6 +27,7 @@ pub struct CommitDetailsComponent {
     file_tree: FileTreeComponent,
     git_commit_files: AsyncCommitFiles,
     visible: bool,
+    key_config: SharedKeyConfig,
 }
 
 impl CommitDetailsComponent {
@@ -36,17 +38,24 @@ impl CommitDetailsComponent {
         queue: &Queue,
         sender: &Sender<AsyncNotification>,
         theme: SharedTheme,
+        key_config: SharedKeyConfig,
     ) -> Self {
         Self {
-            details: DetailsComponent::new(theme.clone()),
+            details: DetailsComponent::new(
+                theme.clone(),
+                key_config.clone(),
+                false,
+            ),
             git_commit_files: AsyncCommitFiles::new(sender),
             file_tree: FileTreeComponent::new(
                 "",
                 false,
                 Some(queue.clone()),
                 theme,
+                key_config.clone(),
             ),
             visible: false,
+            key_config,
         }
     }
 
@@ -55,7 +64,7 @@ impl CommitDetailsComponent {
 
         format!(
             "{} {}",
-            strings::commit::DETAILS_FILES_TITLE,
+            strings::commit::details_files_title(&self.key_config),
             files_count
         )
     }
@@ -146,6 +155,26 @@ impl Component for CommitDetailsComponent {
             return Ok(true);
         }
 
+        if self.focused() {
+            if let Event::Key(e) = ev {
+                return if e == self.key_config.focus_below
+                    && self.details.focused()
+                {
+                    self.details.focus(false);
+                    self.file_tree.focus(true);
+                    Ok(true)
+                } else if e == self.key_config.focus_above
+                    && self.file_tree.focused()
+                {
+                    self.file_tree.focus(false);
+                    self.details.focus(true);
+                    Ok(true)
+                } else {
+                    Ok(false)
+                };
+            }
+        }
+
         Ok(false)
     }
 
@@ -164,6 +193,7 @@ impl Component for CommitDetailsComponent {
         self.details.focused() || self.file_tree.focused()
     }
     fn focus(&mut self, focus: bool) {
+        self.details.focus(false);
         self.file_tree.focus(focus);
         self.file_tree.show_selection(true);
     }
