@@ -1,13 +1,16 @@
-use super::{CommandBlocking, DrawableComponent, ScrollType};
+use super::{
+    CommandBlocking, Direction, DrawableComponent, ScrollType,
+};
 use crate::{
     components::{CommandInfo, Component},
-    keys,
+    keys::SharedKeyConfig,
     queue::{Action, InternalEvent, NeedsUpdate, Queue, ResetItem},
-    strings::{self, commands},
-    ui::{calc_scroll_top, style::SharedTheme},
+    strings, try_or_popup,
+    ui::{self, calc_scroll_top, style::SharedTheme},
 };
 use asyncgit::{hash, sync, DiffLine, DiffLineType, FileDiff, CWD};
 use bytesize::ByteSize;
+use clipboard::{ClipboardContext, ClipboardProvider};
 use crossterm::event::Event;
 use std::{borrow::Cow, cell::Cell, cmp, path::Path};
 use tui::{
@@ -18,7 +21,7 @@ use tui::{
     Frame,
 };
 
-use anyhow::Result;
+use anyhow::{anyhow, Result};
 
 #[derive(Default)]
 struct Current {
@@ -27,23 +30,93 @@ struct Current {
     hash: u64,
 }
 
+///
+#[derive(Clone, Copy)]
+enum Selection {
+    Single(usize),
+    Multiple(usize, usize),
+}
+
+impl Selection {
+    const fn get_start(&self) -> usize {
+        match self {
+            Self::Single(start) | Self::Multiple(start, _) => *start,
+        }
+    }
+
+    const fn get_end(&self) -> usize {
+        match self {
+            Self::Single(end) | Self::Multiple(_, end) => *end,
+        }
+    }
+
+    fn get_top(&self) -> usize {
+        match self {
+            Self::Single(start) => *start,
+            Self::Multiple(start, end) => cmp::min(*start, *end),
+        }
+    }
+
+    fn get_bottom(&self) -> usize {
+        match self {
+            Self::Single(start) => *start,
+            Self::Multiple(start, end) => cmp::max(*start, *end),
+        }
+    }
+
+    fn modify(&mut self, direction: Direction, max: usize) {
+        let start = self.get_start();
+        let old_end = self.get_end();
+
+        *self = match direction {
+            Direction::Up => {
+                Self::Multiple(start, old_end.saturating_sub(1))
+            }
+
+            Direction::Down => {
+                Self::Multiple(start, cmp::min(old_end + 1, max))
+            }
+        };
+    }
+
+    fn contains(&self, index: usize) -> bool {
+        match self {
+            Self::Single(start) => index == *start,
+            Self::Multiple(start, end) => {
+                if start <= end {
+                    *start <= index && index <= *end
+                } else {
+                    *end <= index && index <= *start
+                }
+            }
+        }
+    }
+}
+
 ///
 pub struct DiffComponent {
     diff: Option<FileDiff>,
     pending: bool,
-    selection: usize,
+    selection: Selection,
     selected_hunk: Option<usize>,
     current_size: Cell<(u16, u16)>,
     focused: bool,
     current: Current,
     scroll_top: Cell<usize>,
-    queue: Option<Queue>,
+    queue: Queue,
     theme: SharedTheme,
+    key_config: SharedKeyConfig,
+    is_immutable: bool,
 }
 
 impl DiffComponent {
     ///
-    pub fn new(queue: Option<Queue>, theme: SharedTheme) -> Self {
+    pub fn new(
+        queue: Queue,
+        theme: SharedTheme,
+        key_config: SharedKeyConfig,
+        is_immutable: bool,
+    ) -> Self {
         Self {
             focused: false,
             queue,
@@ -52,9 +125,11 @@ impl DiffComponent {
             selected_hunk: None,
             diff: None,
             current_size: Cell::new((0, 0)),
-            selection: 0,
+            selection: Selection::Single(0),
             scroll_top: Cell::new(0),
             theme,
+            key_config,
+            is_immutable,
         }
     }
     ///
@@ -73,7 +148,7 @@ impl DiffComponent {
         self.current = Current::default();
         self.diff = None;
         self.scroll_top.set(0);
-        self.selection = 0;
+        self.selection = Selection::Single(0);
         self.selected_hunk = None;
         self.pending = pending;
 
@@ -97,12 +172,14 @@ impl DiffComponent {
                 hash,
             };
 
-            self.selected_hunk =
-                Self::find_selected_hunk(&diff, self.selection)?;
+            self.selected_hunk = Self::find_selected_hunk(
+                &diff,
+                self.selection.get_start(),
+            )?;
 
             self.diff = Some(diff);
             self.scroll_top.set(0);
-            self.selection = 0;
+            self.selection = Selection::Single(0);
         }
 
         Ok(())
@@ -113,37 +190,104 @@ impl DiffComponent {
         move_type: ScrollType,
     ) -> Result<()> {
         if let Some(diff) = &self.diff {
-            let old = self.selection;
-
             let max = diff.lines.saturating_sub(1) as usize;
 
-            self.selection = match move_type {
-                ScrollType::Down => old.saturating_add(1),
-                ScrollType::Up => old.saturating_sub(1),
+            let new_start = match move_type {
+                ScrollType::Down => {
+                    self.selection.get_bottom().saturating_add(1)
+                }
+                ScrollType::Up => {
+                    self.selection.get_top().saturating_sub(1)
+                }
                 ScrollType::Home => 0,
                 ScrollType::End => max,
                 ScrollType::PageDown => {
-                    self.selection.saturating_add(
+                    self.selection.get_bottom().saturating_add(
+                        self.current_size.get().1.saturating_sub(1)
+                            as usize,
+                    )
+                }
+                ScrollType::PageUp => {
+                    self.selection.get_top().saturating_sub(
                         self.current_size.get().1.saturating_sub(1)
                             as usize,
                     )
                 }
-                ScrollType::PageUp => self.selection.saturating_sub(
-                    self.current_size.get().1.saturating_sub(1)
-                        as usize,
-                ),
             };
 
-            self.selection = cmp::min(max, self.selection);
+            let new_start = cmp::min(max, new_start);
 
-            if old != self.selection {
-                self.selected_hunk =
-                    Self::find_selected_hunk(diff, self.selection)?;
-            }
+            self.selection = Selection::Single(new_start);
+
+            self.selected_hunk =
+                Self::find_selected_hunk(diff, new_start)?;
         }
         Ok(())
     }
 
+    fn lines_count(&self) -> usize {
+        self.diff
+            .as_ref()
+            .map_or(0, |diff| diff.lines.saturating_sub(1))
+    }
+
+    fn modify_selection(
+        &mut self,
+        direction: Direction,
+    ) -> Result<()> {
+        if let Some(diff) = &self.diff {
+            let max = diff.lines.saturating_sub(1);
+
+            self.selection.modify(direction, max);
+        }
+
+        Ok(())
+    }
+
+    fn copy_string(string: String) -> Result<()> {
+        let mut ctx: ClipboardContext = ClipboardProvider::new()
+            .map_err(|_| {
+                anyhow!("failed to get access to clipboard")
+            })?;
+        ctx.set_contents(string).map_err(|_| {
+            anyhow!("failed to set clipboard contents")
+        })?;
+
+        Ok(())
+    }
+
+    fn copy_selection(&self) -> Result<()> {
+        if let Some(diff) = &self.diff {
+            let lines_to_copy: Vec<&str> = diff
+                .hunks
+                .iter()
+                .flat_map(|hunk| hunk.lines.iter())
+                .enumerate()
+                .filter_map(|(i, line)| {
+                    if self.selection.contains(i) {
+                        Some(
+                            line.content
+                                .trim_matches(|c| {
+                                    c == '\n' || c == '\r'
+                                })
+                                .as_ref(),
+                        )
+                    } else {
+                        None
+                    }
+                })
+                .collect();
+
+            try_or_popup!(
+                self,
+                "copy to clipboard error:",
+                Self::copy_string(lines_to_copy.join("\n"))
+            );
+        }
+
+        Ok(())
+    }
+
     fn find_selected_hunk(
         diff: &FileDiff,
         line_selected: usize,
@@ -210,8 +354,6 @@ impl DiffComponent {
                     Text::Raw(Cow::from(")")),
                 ]);
             } else {
-                let selection = self.selection;
-
                 let min = self.scroll_top.get();
                 let max = min + height as usize;
 
@@ -242,7 +384,8 @@ impl DiffComponent {
                                     &mut res,
                                     width,
                                     line,
-                                    selection == line_cursor,
+                                    self.selection
+                                        .contains(line_cursor),
                                     hunk_selected,
                                     i == hunk_len as usize - 1,
                                     &self.theme,
@@ -311,7 +454,7 @@ impl DiffComponent {
         ));
     }
 
-    fn hunk_visible(
+    const fn hunk_visible(
         hunk_min: usize,
         hunk_max: usize,
         min: usize,
@@ -369,7 +512,6 @@ impl DiffComponent {
     fn queue_update(&mut self) {
         self.queue
             .as_ref()
-            .expect("try using queue in immutable diff")
             .borrow_mut()
             .push_back(InternalEvent::Update(NeedsUpdate::ALL));
     }
@@ -379,40 +521,28 @@ impl DiffComponent {
             if let Some(hunk) = self.selected_hunk {
                 let hash = diff.hunks[hunk].header_hash;
 
-                self.queue
-                    .as_ref()
-                    .expect("try using queue in immutable diff")
-                    .borrow_mut()
-                    .push_back(InternalEvent::ConfirmAction(
-                        Action::ResetHunk(
-                            self.current.path.clone(),
-                            hash,
-                        ),
-                    ));
+                self.queue.as_ref().borrow_mut().push_back(
+                    InternalEvent::ConfirmAction(Action::ResetHunk(
+                        self.current.path.clone(),
+                        hash,
+                    )),
+                );
             }
         }
         Ok(())
     }
 
     fn reset_untracked(&self) -> Result<()> {
-        self.queue
-            .as_ref()
-            .expect("try using queue in immutable diff")
-            .borrow_mut()
-            .push_back(InternalEvent::ConfirmAction(Action::Reset(
-                ResetItem {
-                    path: self.current.path.clone(),
-                    is_folder: false,
-                },
-            )));
+        self.queue.as_ref().borrow_mut().push_back(
+            InternalEvent::ConfirmAction(Action::Reset(ResetItem {
+                path: self.current.path.clone(),
+                is_folder: false,
+            })),
+        );
 
         Ok(())
     }
 
-    fn is_immutable(&self) -> bool {
-        self.queue.is_none()
-    }
-
     const fn is_stage(&self) -> bool {
         self.current.is_stage
     }
@@ -432,15 +562,18 @@ impl DrawableComponent for DiffComponent {
         self.scroll_top.set(calc_scroll_top(
             self.scroll_top.get(),
             self.current_size.get().1 as usize,
-            self.selection,
+            self.selection.get_end(),
         ));
 
-        let title =
-            format!("{}{}", strings::TITLE_DIFF, self.current.path);
+        let title = format!(
+            "{}{}",
+            strings::title_diff(&self.key_config),
+            self.current.path
+        );
 
         let txt = if self.pending {
             vec![Text::Styled(
-                Cow::from(strings::LOADING_TEXT),
+                Cow::from(strings::loading_text(&self.key_config)),
                 self.theme.text(false, false),
             )]
         } else {
@@ -457,6 +590,15 @@ impl DrawableComponent for DiffComponent {
             ),
             r,
         );
+        if self.focused {
+            ui::draw_scrollbar(
+                f,
+                r,
+                &self.theme,
+                self.lines_count(),
+                self.selection.get_end(),
+            );
+        }
 
         Ok(())
     }
@@ -469,33 +611,39 @@ impl Component for DiffComponent {
         _force_all: bool,
     ) -> CommandBlocking {
         out.push(CommandInfo::new(
-            commands::SCROLL,
+            strings::commands::scroll(&self.key_config),
             self.can_scroll(),
             self.focused,
         ));
 
+        out.push(CommandInfo::new(
+            strings::commands::copy(&self.key_config),
+            true,
+            self.focused,
+        ));
+
         out.push(
             CommandInfo::new(
-                commands::DIFF_HOME_END,
+                strings::commands::diff_home_end(&self.key_config),
                 self.can_scroll(),
                 self.focused,
             )
             .hidden(),
         );
 
-        if !self.is_immutable() {
+        if !self.is_immutable {
             out.push(CommandInfo::new(
-                commands::DIFF_HUNK_REMOVE,
+                strings::commands::diff_hunk_remove(&self.key_config),
                 self.selected_hunk.is_some(),
                 self.focused && self.is_stage(),
             ));
             out.push(CommandInfo::new(
-                commands::DIFF_HUNK_ADD,
+                strings::commands::diff_hunk_add(&self.key_config),
                 self.selected_hunk.is_some(),
                 self.focused && !self.is_stage(),
             ));
             out.push(CommandInfo::new(
-                commands::DIFF_HUNK_REVERT,
+                strings::commands::diff_hunk_revert(&self.key_config),
                 self.selected_hunk.is_some(),
                 self.focused && !self.is_stage(),
             ));
@@ -507,53 +655,56 @@ impl Component for DiffComponent {
     fn event(&mut self, ev: Event) -> Result<bool> {
         if self.focused {
             if let Event::Key(e) = ev {
-                return match e {
-                    keys::MOVE_DOWN => {
-                        self.move_selection(ScrollType::Down)?;
-                        Ok(true)
+                return if e == self.key_config.move_down {
+                    self.move_selection(ScrollType::Down)?;
+                    Ok(true)
+                } else if e == self.key_config.shift_down {
+                    self.modify_selection(Direction::Down)?;
+                    Ok(true)
+                } else if e == self.key_config.shift_up {
+                    self.modify_selection(Direction::Up)?;
+                    Ok(true)
+                } else if e == self.key_config.end {
+                    self.move_selection(ScrollType::End)?;
+                    Ok(true)
+                } else if e == self.key_config.home {
+                    self.move_selection(ScrollType::Home)?;
+                    Ok(true)
+                } else if e == self.key_config.move_up {
+                    self.move_selection(ScrollType::Up)?;
+                    Ok(true)
+                } else if e == self.key_config.page_up {
+                    self.move_selection(ScrollType::PageUp)?;
+                    Ok(true)
+                } else if e == self.key_config.page_down {
+                    self.move_selection(ScrollType::PageDown)?;
+                    Ok(true)
+                } else if e == self.key_config.enter
+                    && !self.is_immutable
+                {
+                    if self.current.is_stage {
+                        self.unstage_hunk()?;
+                    } else {
+                        self.stage_hunk()?;
                     }
-                    keys::SHIFT_DOWN | keys::END => {
-                        self.move_selection(ScrollType::End)?;
-                        Ok(true)
-                    }
-                    keys::HOME | keys::SHIFT_UP => {
-                        self.move_selection(ScrollType::Home)?;
-                        Ok(true)
-                    }
-                    keys::MOVE_UP => {
-                        self.move_selection(ScrollType::Up)?;
-                        Ok(true)
-                    }
-                    keys::PAGE_UP => {
-                        self.move_selection(ScrollType::PageUp)?;
-                        Ok(true)
-                    }
-                    keys::PAGE_DOWN => {
-                        self.move_selection(ScrollType::PageDown)?;
-                        Ok(true)
-                    }
-                    keys::ENTER if !self.is_immutable() => {
-                        if self.current.is_stage {
-                            self.unstage_hunk()?;
+                    Ok(true)
+                } else if e == self.key_config.status_reset_item
+                    && !self.is_immutable
+                    && !self.is_stage()
+                {
+                    if let Some(diff) = &self.diff {
+                        if diff.untracked {
+                            self.reset_untracked()?;
                         } else {
-                            self.stage_hunk()?;
+                            self.reset_hunk()?;
                         }
-                        Ok(true)
                     }
-                    keys::DIFF_RESET_HUNK
-                        if !self.is_immutable()
-                            && !self.is_stage() =>
-                    {
-                        if let Some(diff) = &self.diff {
-                            if diff.untracked {
-                                self.reset_untracked()?;
-                            } else {
-                                self.reset_hunk()?;
-                            }
-                        }
-                        Ok(true)
-                    }
-                    _ => Ok(false),
+                    Ok(true)
+                } else if e == self.key_config.copy {
+                    self.copy_selection()?;
+                    Ok(true)
+                } else {
+                    Ok(false)
                 };
             }
         }
