@@ -3,6 +3,7 @@ mod command;
 mod commit;
 mod commit_details;
 mod commitlist;
+mod create_branch;
 mod diff;
 mod externaleditor;
 mod filetree;
@@ -23,6 +24,7 @@ pub use command::{CommandInfo, CommandText};
 pub use commit::CommitComponent;
 pub use commit_details::CommitDetailsComponent;
 pub use commitlist::CommitList;
+pub use create_branch::CreateBranchComponent;
 pub use diff::DiffComponent;
 pub use externaleditor::ExternalEditorComponent;
 pub use filetree::FileTreeComponent;
@@ -105,6 +107,12 @@ pub enum ScrollType {
     PageDown,
 }
 
+#[derive(Copy, Clone)]
+pub enum Direction {
+    Up,
+    Down,
+}
+
 ///
 #[derive(PartialEq)]
 pub enum CommandBlocking {
